==> haskell-digits-0.3.2-9-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-digits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 digits
version:              0.3.2
visibility:           public
id:                   digits-0.3.2-6EcxlzjqdwY1P1YQDL1wR8
key:                  digits-0.3.2-6EcxlzjqdwY1P1YQDL1wR8
license:              BSD-3-Clause
copyright:            (c) 2009-2025 Henry Bucklow, (c) 2016 Charlie Harvey
maintainer:           opensource@elsie.org.uk
author:               Henry Bucklow
synopsis:             Converts integers to lists of digits and back.
description:
    Converts integers to lists of digits and back. Supports arbitrary bases.

category:             Data
abi:                  2a5b6366cc3c9b0ea37d339759feddd2
exposed:              True
exposed-modules:      Data.Digits
import-dirs:          /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-digits
hs-libraries:         HSdigits-0.3.2-6EcxlzjqdwY1P1YQDL1wR8
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1

haddock-interfaces:   /usr/share/doc/haskell-digits/html/digits.haddock
haddock-html:         /usr/share/doc/haskell-digits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digits-0.3.2-10-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-digits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 digits
version:              0.3.2
visibility:           public
id:                   digits-0.3.2-7Ao9B9xod7t6l0DPl8nr8H
key:                  digits-0.3.2-7Ao9B9xod7t6l0DPl8nr8H
license:              BSD-3-Clause
copyright:            (c) 2009-2025 Henry Bucklow, (c) 2016 Charlie Harvey
maintainer:           opensource@elsie.org.uk
author:               Henry Bucklow
synopsis:             Converts integers to lists of digits and back.
description:
    Converts integers to lists of digits and back. Supports arbitrary bases.

category:             Data
abi:                  29170cdada8e32184019f6594d808506
exposed:              True
exposed-modules:      Data.Digits
import-dirs:          /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-digits
hs-libraries:         HSdigits-0.3.2-7Ao9B9xod7t6l0DPl8nr8H
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1

haddock-interfaces:   /usr/share/doc/haskell-digits/html/digits.haddock
haddock-html:         /usr/share/doc/haskell-digits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
